@@ -31,7 +31,9 @@
  * OF THIS SOFTWARE.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -39,7 +41,15 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#ifndef WIN32
 #include <unistd.h>
+#else
+#include <io.h>
+#define open _open
+#define close _close
+#define read _read
+#define lseek _lseek
+#endif
 
 #ifdef HAVE_BYTESWAP_H
 #include <byteswap.h>
@@ -52,12 +62,19 @@
       (((*x) & 0x0000ff00u) <<  8) | (((*x) & 0x000000ffu) << 24))
 #endif
 
+#ifdef WIN32
+typedef short int16;
+typedef unsigned short uint16;
+typedef int int32;
+typedef unsigned int uint32;
+#else
 #include <inttypes.h>
 
 typedef int16_t int16;
 typedef uint16_t uint16;
 typedef int32_t int32;
 typedef uint32_t uint32;
+#endif
 
 #include "bmp.h"
 
@@ -258,6 +275,16 @@ rearrangePixels(unsigned char* buf, uint32 width, uint32 bit_count)
   }
 }
 
+static int last_bit_set (int v)
+{
+	unsigned int i;
+	for (i = sizeof (int) * 8 - 1; i > 0; --i) {
+		if (v & (1L << i))
+			return i;
+	}
+	return 0;
+}
+			
 unsigned char* read_bmp (PSDoc *psdoc, const char* file, int* w, int* h,
 		int* bps, int* spp, int* xres, int* yres,
 		unsigned char** color_table, int* color_table_size,
@@ -350,8 +377,8 @@ unsigned char* read_bmp (PSDoc *psdoc, const char* file, int* w, int* h,
 		BMPSwabLong(&info_hdr.iAlphaMask);
 #endif
 		n_clr_elems = 4;
-		*xres = ((double)info_hdr.iXPelsPerMeter * 2.54 + 0.05) / 100;
-		*yres = ((double)info_hdr.iYPelsPerMeter * 2.54 + 0.05) / 100;
+		*xres = (int) ((double)info_hdr.iXPelsPerMeter * 2.54 + 0.05) / 100;
+		*yres = (int) ((double)info_hdr.iYPelsPerMeter * 2.54 + 0.05) / 100;
 	}
 
 	if (bmp_type == BMPT_OS22) {
@@ -505,16 +532,6 @@ unsigned char* read_bmp (PSDoc *psdoc, const char* file, int* w, int* h,
 	
 				// convert to RGB
 				if (info_hdr.iCompression == BMPC_BITFIELDS) {
-		 			int last_bit_set (int v)
-		 			{
-			 			unsigned int i;
-			 			for (i = sizeof (int) * 8 - 1; i > 0; --i) {
-							if (v & (1L << i))
-								return i;
-			 			}
-			 			return 0;
-					}
-			
 					unsigned char* row_ptr = data + stride*row;
 					unsigned char* r16_ptr = row_ptr + file_stride - 2;
 					unsigned char* rgb_ptr = row_ptr + stride - 3;
