@@ -19,7 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: ght_hash_table.h.in,v 1.2 2007/06/23 20:47:15 steinm Exp $
+ * $Id: ght_hash_table.h.in,v 1.4 2007/07/04 13:07:59 steinm Exp $
  *
  ********************************************************************/
 
@@ -60,6 +60,9 @@
 #define GHT_HASH_TABLE_H
 
 #include <stdlib.h>                    /* size_t */
+#ifndef WIN32
+#include <stdint.h>                    /* uint32_t */
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -80,7 +83,11 @@ extern "C" {
 
 /** unsigned 32 bit integer. */
 /*typedef unsigned  _ght_uint32_t;*/
-typedef u_int32_t ght_uint32_t;
+#ifndef WIN32
+typedef uint32_t ght_uint32_t;
+#else
+typedef unsigned int ght_uint32_t;
+#endif
 
 /**
  * The structure for hash keys. You should not care about this
