@@ -20,7 +20,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: hash_table.c,v 1.3 2007/07/04 13:07:59 steinm Exp $
+ * $Id: hash_table.c,v 1.4 2009/03/05 20:01:46 steinm Exp $
  *
  ********************************************************************/
 
@@ -32,7 +32,7 @@
 
 #include "ght_hash_table.h"
 
-#ifdef WIN32
+#if defined(WIN32) || defined(__hpux)
 #define PSLIB_INLINE
 #else
 #define PSLIB_INLINE inline
