@@ -1,6 +1,6 @@
 #ifndef __PS_FONTENC_H__
 #define __PS_FONTENC_H__
 
-extern ENCODING fontencoding;
+extern ENCODING fontencoding[];
 
 #endif
