@@ -18,7 +18,7 @@
  *    Boston, MA 02111-1307, USA.
  */
 
-/* $Id: ps_util.c,v 1.44 2007/07/11 16:03:57 steinm Exp $ */
+/* $Id: ps_util.c,v 1.45 2008/01/04 07:39:31 steinm Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -480,7 +480,7 @@ ght_hash_table_t *ps_build_enc_from_font(PSDoc *psdoc, ADOBEFONTMETRIC *metrics)
 			/* Do not add glyphs with a number <= 0 */
 			if(p_e->adobenum > 0) {
 				if(0 > ght_insert(hashvec, (char *) p_e->adobenum+1, strlen(p_e->adobename)+1, p_e->adobename))
-				fprintf(stderr, "Could not insert entry %d->%s into font encoding hash table.\n", p_e->adobenum, p_e->adobename);
+				ps_error(psdoc, PS_Warning, _("Could not insert entry %d->%s into font encoding hash table."), p_e->adobenum, p_e->adobename);
 			}
 		}
 	}
@@ -802,6 +802,21 @@ ght_hash_table_t *ps_parse_optlist(PSDoc *psdoc, const char *optstr) {
 }
 /* }}} */
 
+/* ps_free_optlist() {{{
+ */
+void ps_free_optlist(PSDoc *psdoc, ght_hash_table_t *opthash) {
+	ght_iterator_t iterator;
+	char *strval, *key;
+
+//		fprintf(stderr, "Freeing optlist\n");
+	for(strval = ght_first(opthash, &iterator, (void **) &key); strval; strval = ght_next(opthash, &iterator, (void **) &key)) {
+//		fprintf(stderr, "Freeing %s\n", strval);
+		psdoc->free(psdoc, strval);
+	}
+	ght_finalize(opthash);
+}
+/* }}} */
+
 /* get_optlist_element_as_float() {{{
  * Retrieves an element from the hash and converts its value into float
  * Modifies *value only if the conversion was successful.
